; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
;

;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
[Command]
name = "TripleKFPalm"
command = ~D, DF, F, D, DF, F, x
time = 20

[Command]
name = "TripleKFPalm"   ;Same name as above
command = ~D, DF, F, D, DF, F, y
time = 20

[Command]
name = "SmashKFUpper"
command = ~D, DB, B, D, DB, B, x;~F, D, DF, F, D, DF, x
time = 20

[Command]
name = "SmashKFUpper"   ;Same name as above
command = ~D, DB, B, D, DB, B, y;~F, D, DF, F, D, DF, y
time = 20

;-| Special Motions |------------------------------------------------------
[Command]
name = "upper_x"
command = ~F, D, DF, x

[Command]
name = "upper_y"
command = ~F, D, DF, y

[Command]
name = "upper_z"
command = ~F, D, DF, z

[Command]
name = "upper_xy"
command = ~D,DF,F,x+c;F, D, DF, x+y

[Command]
name = "zigzag_2p"
command = ~D,DF,F,z+c;F, D, DF, x+y

[Command]
name = "HCB_x"
command = ~F, DF, D, DB, B, x
time = 30

[Command]
name = "HCB_x"
command = ~F, D, B, x
time = 30

[Command]
name = "HCB_y"
command = ~F, DF, D, DB, B, y
time = 30

[Command]
name = "HCB_y"
command = ~F, D, B, y
time = 30

[Command]
name = "HCB_z"
command = ~F, DF, D, DB, B, z
time = 30

[Command]
name = "HCB_z"
command = ~F, D, B, z
time = 30

[Command]
name = "HCF_x"
command = ~B, DB, D, DF, F, x
time = 30

[Command]
name = "HCF_x"
command = ~B, D, F, x
time = 30

[Command]
name = "HCF_y"
command = ~B, DB, D, DF, F, y
time = 30

[Command]
name = "HCF_y"
command = ~B, D, F, y
time = 30

[Command]
name = "HCF_z"
command = ~B, DB, D, DF, F, z
time = 30

[Command]
name = "HCF_z"
command = ~B, D, F, z
time = 30

[Command]
name = "QCF_a"
command = ~D, DF, F, a
time = 15

[Command]
name = "QCF_b"
command = ~D, DF, F, b
time = 15

[Command]
name = "QCF_c"
command = ~D, DF, F, c
time = 15

[Command]
name = "QCF_x"
command = ~D, DF, F, x
time = 15

[Command]
name = "QCF_y"
command = ~D, DF, F, y
time = 15

[Command]
name = "QCF_z"
command = ~D, DF, F, z
time = 15

[Command]
name = "QCF_xy"
command = ~D, DF, F, x+y

[Command]
name = "QCB_a"
command = ~D, DB, B, a
time = 15

[Command]
name = "QCB_b"
command = ~D, DB, B, b
time = 15

[Command]
name = "QCB_c"
command = ~D, DB, B, c
time = 15

[Command]
name = "QCF_2k"
command = ~D, DF, F, a+b

[Command]
name = "QCF_2k"
command = ~D, DF, F, a+c

[Command]
name = "QCF_2k"
command = ~D, DF, F, b+c

[Command]
name = "QCB_2k"
command = ~D, DB, B, a+b

[Command]
name = "QCB_2k"
command = ~D, DB, B, a+c

[Command]
name = "QCB_2k"
command = ~D, DB, B, b+c

[Command]
name = "HCF_2p"
command = ~B, DB, D, DF, F, a+b

[Command]
name = "HCF_2p"
command = ~B, DB, D, DF, F, a+c

[Command]
name = "HCF_2p"
command = ~B, DB, D, DF, F, b+c

[Command]
name = "QCF_2p"
command = ~D, DF, F, x+y

[Command]
name = "QCF_2p"
command = ~D, DF, F, x+z

[Command]
name = "QCF_2p"
command = ~D, DF, F, y+z

[Command]
name = "QCB_2p"
command = ~D, DB, B, x+y

[Command]
name = "QCB_2p"
command = ~D, DB, B, x+z

[Command]
name = "QCB_2p"
command = ~D, DB, B, y+z


[Command]
name = "qcb_2k"
command = ~D, DB, B, a+b

[Command]
name = "qcb_2k"
command = ~D, DB, B, a+c

[Command]
name = "qcb_2k"
command = ~D, DB, B, b+c

[Command]
name = "FF_ab"
command = F, F, a+b

[Command]
name = "FF_a"
command = F, F, a

[Command]
name = "FF_b"
command = F, F, b

[Command]
name = "pushback"
command = y+b

[Command]
name = "launcher"
command = x+a

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "FWD_y"
command = /$F,y
time = 1

[Command]
name = "FWD_z"
command = /$F,z
time = 1

[Command]
name = "FWD_b"
command = /$F,b
time = 1

[Command]
name = "FWD_c"
command = /$F,c
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "counter"
command = /$B, x + a

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

[Command]
name = "DU"
command = D, U
time = 15

[Command]
name = "DU"
command = D, UB
time = 15

[Command]
name = "DU"
command = D, UF
time = 15

[Command]
name = "airfollow"
command = U

[Command]
name = "airfollow"
command = UF

[Command]
name = "airfollow" ;Required (do not remove)
command = /$U
time = 1


;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

[Command]
name = "CPU1"
command = D, D, U, U, D, U
time = 1

[Command]
name = "CPU2"
command = D, F, D, F, F, D, F
time = 1

[Command]
name = "CPU3"
command = B, D, F, B, B, D
time = 1

[Command]
name = "CPU4"
command = D, D, U, U, D, U, F, U
time = 1

[Command]
name = "CPU5"
command = D, F, D, F, F, D, F, U, U
time = 1

[Command]
name = "CPU6"
command = B, D, F, B, B, D, U
time = 1

[Command]
name = "CPU7"
command = B, F, B, F, F, D, F, U, U, U
time = 1

[Command]
name = "CPU8"
command = B, F, F, B, F, D, U, U
time = 1

[Command]
name = "CPU9"
command = D, F, D, F, F, D, F, U, U, F, U, U, B
time = 1

[Command]
name = "CPU10"
command = B, D, F, B, B, B, B
time = 1

[Command]
name = "CPU11"
command = D, F, D, F, F, D, F, U, U, B, B, U, F
time = 1

[Command]
name = "CPU12"
command = B, D, D, B, B, D, U, U, U, F
time = 1

[Command]
name = "CPU13"
command = D, F, D, F, F, D, F, U, B, B, B, U
time = 1

[Command]
name = "CPU14"
command = B, D, F, B, B, D, F, U, B, F, U
time = 1

[Command]
name = "Hyper1"
command = F, F, D, D, F, B
time = 1

[Command]
name = "Hyper2"
command = F, B, F, D, F, F, F, B
time = 1

[Command]
name = "Hyper3"
command = F, B, F, D, F, F, F, B, F, B
time = 1

[Command]
name = "Hyper4"
command = F, B, F, D, F, F, F, B
time = 1

[Command]
name = "Hyper5"
command = F, B, F, D, F, F, F, B, F, B, D, F, D
time = 1

[Command]
name = "Hyper6"
command = F, B, F, D, F, F, F, B, D, D
time = 1

[Command]
name = "Hyper7"
command = F, B, F, D, F, F, F, B, F, B, F
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------

;===========================================================================
;---------------------------------------------------------------------------

[State -1, SetAIVar]
type = varset
v = 59
value = 1
triggerall = var(59) = 0
trigger1 = (command = "CPU1") && const(data.sparkno) != 0
trigger2 = (command = "CPU2") && const(data.sparkno) != 0
trigger3 = (command = "CPU3") && const(data.sparkno) != 0
trigger4 = (command = "CPU4") && const(data.sparkno) != 0
trigger5 = (command = "CPU5") && const(data.sparkno) != 0
trigger6 = (command = "CPU6") && const(data.sparkno) != 0
trigger7 = (command = "Hyper1") && const(data.sparkno) != 0
trigger8 = (command = "Hyper2") && const(data.sparkno) != 0
trigger9 = (command = "Hyper3") && const(data.sparkno) != 0
trigger10 = (command = "Hyper4") && const(data.sparkno) != 0
trigger11 = (command = "Hyper5") && const(data.sparkno) != 0
trigger12 = (command = "Hyper6") && const(data.sparkno) != 0
trigger13 = (command = "Hyper7") && const(data.sparkno) != 0
trigger14 = (command = "CPU7") && const(data.sparkno) != 0
trigger15 = (command = "CPU8") && const(data.sparkno) != 0
trigger16 = (command = "CPU9") && const(data.sparkno) != 0
trigger17 = (command = "CPU10") && const(data.sparkno) != 0
trigger18 = (command = "CPU11") && const(data.sparkno) != 0
trigger19 = (command = "CPU12") && const(data.sparkno) != 0
trigger20 = (command = "CPU13") && const(data.sparkno) != 0
trigger21 = (command = "CPU14") && const(data.sparkno) != 0

;Ground Counter
[State -1, GroundCounter]
type = ChangeState
value = 900
triggerall = stateno = 150 || stateno = 151
trigger1 = (command = "counter") && power >= 1000 && (Statetype != A) && ctrl
trigger2 = var(59) = 1 && random > 995 && power >= 1000 && (Statetype != A) && ctrl

;Air Counter
[State -1, AirCounter]
type = ChangeState
value = 901
triggerall = stateno = 154
trigger1 = (command = "counter") && power >= 1000 && (Statetype = A) && ctrl
trigger2 = var(59) = 1 && random > 995 && power >= 1000 && (Statetype = A) && ctrl

;Dash Forward
[State -1, Dash Forward]
type = ChangeState
value = 161
trigger1 = (command = "FF") && (ctrl) && (var(59) = 0) && (stateno != 161) && (Statetype != A)
trigger2 = (var(59) = 1) && (ctrl) && (P2BodyDist X = [200, 400]) && (random > 990) && (Statetype != A)

;Air Dash Forward
[State -1, Dash Forward Air]
type = ChangeState
value = 800
trigger1 = (command = "FF") && (ctrl) && (var(59) = 0) && (pos y < -20) && (stateno != 161) && (Statetype = A) && (frontedgebodydist > 44)
trigger2 = (var(59) = 1) && (ctrl) && (p2bodydist x > 150) && (random > 900)&& (pos y < -50) && (Statetype = A) && (frontedgebodydist > 44)

;AI
[State -1,AI Combo]
type = ChangeState
value = 3501
triggerall = (var(59) = 1) && (ctrl)
trigger1 = (P2BodyDist X = [0, 40]) && (P2BodyDist y = [-10, 10]) && (random > 990) && p2life > 0 && var(26) = 0

;Dash Backward
[State -1, Dash Backward]
type = ChangeState
value = 162
trigger1 = (command = "BB") && (ctrl) && (var(59) = 0) && (Statetype != A)
trigger2 = (var(59) = 1) && (ctrl) && (P2BodyDist X = [0, 100]) && (backedgedist > 200) && random >= 990 && (Statetype != A)

;Super Jump
[State -1, Super Jump]
type = ChangeState
value = 41
trigger1 = (command = "DU") && (Statetype != A) && (ctrl)

[State -1, Iron Spider]
type = ChangeState
value = 3000
trigger1 = (command = "zigzag_2p") && (ctrl) && (power >= 1000) && (var(59) = 0) && p2life > 0 && (Statetype = S)
trigger2 = (var(59) = 1) && (ctrl) && (power >= 1000) && (P2BodyDist X >= 80) && random >= 900 && var(24) = 0 && p2life > 0 && (Statetype = S)

[State -1, Symbiote Snakes]
type = ChangeState
value =  4002
trigger1 = (command = "QCB_2k") && (ctrl) && (power >= 1000) && (var(59) = 0) && p2life > 0 && (Statetype = S)
trigger2 = (var(59) = 1) && (ctrl) && (power >= 1000) && (P2BodyDist X > 40) && random >= 900 && var(24) = 0  && p2life > 0 && (Statetype = S)

[State -1, Maximum Spider]
type = ChangeState
value =  1500
trigger1 = (command = "QCF_2p") && (ctrl) && (power >= 1000) && (var(59) = 0) && p2life > 0
trigger2 = (var(59) = 1) && (ctrl) && (power >= 1000) && (P2BodyDist X > 40) && random >= 900 && var(24) = 0 && p2life > 0

[State -1, Crawler Assault]
type = ChangeState
value = 4000
trigger1 = (command = "QCF_2k") && (ctrl) && (power >= 1000) && (var(59) = 0) && p2life > 0 && (Statetype = S)
trigger2 = (var(59) = 1) && (ctrl) && (power >= 1000) && (P2BodyDist X = [0,100]) && random >= 900 && var(24) = 0 && p2life > 0 && (Statetype = S)

[State -1, Ultimate Web Throw]
type = ChangeState
value =  4500
trigger1 = (command = "QCB_2p") && (ctrl) && (power >= 1000) && (var(59) = 0) && p2life > 0 && (Statetype = S)
trigger2 = (var(59) = 1) && (ctrl) && (power >= 1000) && (P2BodyDist X = [0,200]) && random >= 900 && var(24) = 0 && p2life > 0 && (Statetype = S)

[State -1, Spin Throw]
type = ChangeState
value = 1900
;trigger3 = (command = "FWD_b") && (ctrl) && (P2BodyDist X = [0, 10]) && (ctrl) && (P2BodyDist y = [-40, 40]) && p2statetype != L
trigger1 = (command = "FWD_c") && (ctrl) && (P2BodyDist X = [0, 10]) && (ctrl) && (P2BodyDist y = [-40, 40]) && p2statetype != L
trigger2 = (var(59) = 1) && (ctrl) && var(25) != 1900 && var(26) = 0 && (P2BodyDist X = [0, 10]) && (P2BodyDist y = [-40, 40]) && p2statetype != L && random >= 940

[State -1, Throw]
type = ChangeState
value = 1800
;trigger3 = (command = "FWD_y") && (ctrl) && (P2BodyDist X = [0, 10]) && (Statetype = S) && p2statetype != L
trigger1 = (command = "FWD_z") && (ctrl) && (P2BodyDist X = [0, 10]) && (Statetype = S) && p2statetype != L
trigger2 = (var(59) = 1) && (ctrl) && var(25) != 1118 && var(26) = 0 &&(P2BodyDist X = [0, 10]) && random >= 900 && (Statetype = S) && p2statetype != L

[State -1, web throw straight]
type = ChangeState
value = 1111
trigger1 = (command = "HCB_x") && (ctrl) &&  var(59) = 0 && (Statetype = S)
trigger2 = var(59) = 1 && (ctrl) && var(25) != 1111 && var(26) = 0 && (p2bodydist x >= 80) && numhelper(1112) = 0 && random >= 950 && (Statetype = S)

[State -1, web throw diagonal]
type = ChangeState
value = 1117
trigger1 = (command = "HCB_y") && (ctrl) &&  var(59) = 0 && (Statetype = S)
trigger2 = var(59) = 1 && (ctrl) && var(25) != 1117 && var(26) = 0 && p2bodydist y < -20 && (p2bodydist x >= 80) && numhelper(1112) = 0 && random >= 950 && (Statetype = S)

[State -1, web throw up]
type = ChangeState
value = 1119
trigger1 = (command = "HCB_z") && (ctrl) &&  var(59) = 0 && (Statetype = S)
trigger2 = var(59) = 1 && (ctrl) && var(25) != 1119 && var(26) = 0 && p2bodydist y < -20 && (p2bodydist x < 80) && (p2bodydist x >= 80) && numhelper(1112) = 0 && random >= 950 && (Statetype = S)

[State -1, Spider Sting Light]
type = ChangeState
value = 660
trigger1 = command = "upper_x" && (ctrl) && (statetype != A) && (var(59) = 0)

[State -1, Spider Sting Medium]
type = ChangeState
value = 661
trigger1 = command = "upper_y" && (ctrl) && (statetype != A) && (var(59) = 0)
trigger2 = (var(59) = 1) && (ctrl) && var(25) != 661 && var(26) = 0 && (P2BodyDist X = [0, 50]) && (P2BodyDist y = [-80, 80]) && random >= 990 && (statetype != A)

[State -1, Spider Sting Strong]
type = ChangeState
value = 662
trigger1 = command = "upper_z" && (ctrl) && (statetype != A) && (var(59) = 0)

[State -1, web ball stand]
type = ChangeState
value = 1100
trigger1 = (command = "QCF_x") && (ctrl) && (Statetype = S) && numhelper(1101) = 0 && numhelper(1107) = 0 && p2stateno != 1103
trigger2 = (command = "QCF_y") && (ctrl) && (Statetype = S) && numhelper(1101) = 0 && numhelper(1107) = 0 && p2stateno != 1103
trigger3 = (command = "QCF_z") && (ctrl) && (Statetype = S) && numhelper(1101) = 0 && numhelper(1107) = 0 && p2stateno != 1103
trigger4 = var(59) = 1 && (ctrl) && var(25) != 1100 && var(26) = 0 && (Statetype = S) && (p2bodydist x >= 80) && numhelper(1101) = 0 && p2stateno != 1103 && random >= 950

[State -1, web ball air]
type = ChangeState
value = 1106
trigger1 = (command = "QCF_x") && (ctrl) && (Statetype = a) && numhelper(1107) = 0 && numhelper(1101) = 0 && p2stateno != 1103
trigger2 = (command = "QCF_y") && (ctrl) && (Statetype = a) && numhelper(1107) = 0 && numhelper(1101) = 0 && p2stateno != 1103
trigger3 = (command = "QCF_z") && (ctrl) && (Statetype = a) && numhelper(1107) = 0 && numhelper(1101) = 0 && p2stateno != 1103
trigger4 = var(59) = 1 && (ctrl) && var(25) != 1106 && var(26) = 0 && (Statetype = a) && numhelper(1107) = 0 && numhelper(1101) = 0 && p2stateno != 1103 && (p2bodydist x >= 80) && pos y < -40 && random >= 900

[State -1, web swing light]
type = ChangeState
value = 1110
triggerall = (command = "QCB_a")
trigger1 = (ctrl) && var(59) = 0

[State -1, web swing medium]
type = ChangeState
value = 1060
trigger1 = (command = "QCB_b") && (ctrl) && var(59) = 0
trigger2 = var(59) = 1 && (ctrl) && var(25) != 1110 && var(26) = 0 && random >= 900 && (P2BodyDist y = [-30, 30])

[State -1, web swing strong]
type = ChangeState
value = 1061
triggerall = (command = "QCB_c")
trigger1 = (ctrl) && var(59) = 0

[State -1, WallCling]
type = ChangeState
value = 4400
trigger1 = command = "holdfwd" && ctrl && var(59) = 0 && prevstateno != 4400 && vel y > 0 && (backedgebodydist = [-10,10]) && (pos y < -80) && prevstateno != [600,650]
trigger2 = var(59) = 1 && ctrl && random >= 900 && vel y > 0 && (backedgebodydist = [-10,10]) && (pos y < -80) && prevstateno != [600,650]

;Recover Roll
[State -1, Roll Forward]
type = ChangeState
value = 4800
trigger1 = command = "holdfwd" && var(59) = 0 && (stateno = 5120) && life
trigger2 = var(59) = 1 && (P2BodyDist X = [0, 20]) && random >= 990 && (stateno = 5120) && life

[State -1, Roll Back]
type = ChangeState
value = 4801
trigger1 = command = "holdback" && var(59) = 0 && (stateno = 5120) && life
trigger2 = var(59) = 1 && (P2BodyDist X = [0, 20]) && random >= 990 && (stateno = 5120) && life

;Stand Light Punch
[State -1, Stand Light Punch]
type = ChangeState
value = 200
trigger1 = command = "x" && (ctrl) && command != "holddown" && (var(59) = 0) && (statetype = S) && (stateno != 200)
trigger2 = (var(59) = 1) && (ctrl) && var(25) != 200 && var(26) = 0 && (P2BodyDist X = [0, 60]) && (P2BodyDist y = [-80, 80]) && random >= 900 && (statetype = S)

;---------------------------------------------------------------------------
;Stand Medium Punch
[State -1, Stand Medium Punch]
type = ChangeState
value = 210
trigger1 = command = "y" && (command != "holddown") && (ctrl) && (statetype = S) && (var(59) = 0) && (ctrl)
trigger2 = (var(59) = 1) && (ctrl) && (statetype = S) && var(25) != 210 && var(26) = 0 && (P2BodyDist X = [0, 80]) && (P2BodyDist y = [-80, 80]) && random >= 900

;Stand Strong Punch
[State -1, Stand Strong Punch]
type = ChangeState
value = 220
trigger1 = (command = "z") && (command != "holddown") && (ctrl) && (statetype = S) && (var(59) = 0)
trigger2 = (var(59) = 1) && (ctrl) && (statetype = S) && var(25) != 220 && var(26) = 0 && (P2BodyDist X = [0, 100]) && (P2BodyDist y = [-80, 80]) && random >= 900

;---------------------------------------------------------------------------
;Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
trigger1 =  command = "a" && (command != "holddown") && (ctrl) && (statetype = S) && (var(59) = 0)
trigger2 = (var(59) = 1) && (ctrl) && (statetype = S) && var(25) != 230 && var(26) = 0 && (P2BodyDist X = [0, 50]) && (P2BodyDist y = [-80, 80]) && random >= 900
trigger3 =  command = "a" && (command != "holddown") && (stateno=200) && (var(59) = 0)

;---------------------------------------------------------------------------
;Standing Medium Kick
[State -1, Standing Medium Kick]
type = ChangeState
value = 240
trigger1 = command = "b" && command != "holddown" && (ctrl) && (statetype = S) && (var(59) = 0)
trigger2 = (var(59) = 1) && (ctrl) && (statetype = S) && var(25) != 240 && var(26) = 0 && (P2BodyDist X = [0, 80]) && (P2BodyDist y = [-80, 80]) && random >= 900

;Standing Strong Kick
[State -1, Standing Strong Kick]
type = ChangeState
value = 250
trigger1 = command = "c" && command != "holddown" && (ctrl) && (statetype = S) && (var(59) = 0)
trigger2 = (var(59) = 1) && (ctrl) && (statetype = S) && var(25) != 250 && var(26) = 0 && (P2BodyDist X = [0, 150]) && (P2BodyDist y = [-80, 80]) && random >= 900
;---------------------------------------------------------------------------
[State -1, Taunt]
type = ChangeState
value = 195
trigger1 = command = "start" && ctrl && statetype = S && (var(59) = 0)
;---------------------------------------------------------------------------
;Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
trigger1 = command = "x" && command = "holddown" && (ctrl) && (statetype = c) && (var(59) = 0)
trigger2 = (var(59) = 1) && (ctrl) && (statetype = c) && var(25) != 400 && var(26) = 0 && (P2BodyDist X = [0, 60]) && (P2BodyDist y = [-80, 80]) && random >= 900

;---------------------------------------------------------------------------
;Crouching Medium Punch
[State -1, Crouching Medium Punch]
type = ChangeState
value = 410
trigger1 = command = "y" && command = "holddown" && (ctrl) && (statetype = c) && (var(59) = 0)
trigger2 = (var(59) = 1) && (ctrl) && (statetype = c) && var(25) != 400 && var(26) = 0 && (P2BodyDist X = [0, 80]) && (P2BodyDist y = [-80, 80]) && random >= 900

[State -1, Crouching Strong Punch]
type = ChangeState
value = 420
trigger1 = command = "z" && command = "holddown" && (ctrl) && (statetype = c) && (var(59) = 0)
trigger2 = (var(59) = 1) && (ctrl) && (statetype = c) && var(25) != 420 && var(26) = 0 && (P2BodyDist X = [0, 80]) && (P2BodyDist y = [-80, 80]) && random >= 900
;---------------------------------------------------------------------------
;Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
trigger1 = command = "a" && command = "holddown" && (ctrl) && (statetype = c) && (var(59) = 0)
trigger2 = (var(59) = 1) && (ctrl) && (statetype = c) && var(25) != 430 && var(26) = 0 && (P2BodyDist X = [0, 60]) && (P2BodyDist y = [-80, 80]) && random >= 900

;---------------------------------------------------------------------------
;Crouching Strong Kick
[State -1, Crouching medium Kick]
type = ChangeState
value = 440
trigger1 = command = "b"  && command = "holddown" && (ctrl) && (statetype = c) && (var(59) = 0)
trigger2 = (var(59) = 1) && (ctrl) && (statetype = c) && var(25) != 440 && var(26) = 0 && (P2BodyDist X = [0, 80]) && (P2BodyDist y = [-80, 80]) && random >= 900

[State -1, Crouching Strong Kick]
type = ChangeState
value = 450
trigger1 = command = "c" && command = "holddown" && (ctrl) && (statetype = c) && (var(59) = 0)
trigger2 = (var(59) = 1) && (ctrl) && (statetype = c) && var(25) != 450 && var(26) = 0 && (P2BodyDist X = [0, 80]) && (P2BodyDist y = [-80, 80]) && random >= 900
;---------------------------------------------------------------------------
;Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
trigger1 = (command = "x") && (ctrl) && (statetype = A) && (var(59) = 0)
trigger2 = (var(59) = 1) && (ctrl) && (statetype = A) && var(25) != 600 && var(26) = 0 && (P2BodyDist X = [0, 50]) && (P2BodyDist y = [-80, 80]) && random >= 900

;---------------------------------------------------------------------------
;Jump Medium Punch
[State -1, Jump Medium Punch]
type = ChangeState
value = 610
trigger1 = command = "y" && (ctrl) && (statetype = A) && var(59) = 0
trigger2 = (var(59) = 1) && (ctrl) && (statetype = A) && var(25) != 610 && var(26) = 0 &&  (P2BodyDist X = [0, 50]) && (P2BodyDist y = [-80, 80]) && random >= 900

;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 620
trigger1 = (command = "z") && (ctrl) && (statetype = A) && var(59) = 0
trigger2 = (var(59) = 1) && (ctrl) && (statetype = A) && var(25) != 620 && var(26) = 0 && (P2BodyDist X = [0, 60]) && (P2BodyDist y = [-80, 80]) && random >= 900
;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
trigger1 = command = "a" && (ctrl) && (statetype = A) && (var(59) = 0)
trigger2 = (var(59) = 1) && (ctrl) && (statetype = A) && var(25) != 630 && var(26) = 0 && (P2BodyDist X = [0, 50]) && random >= 900

;---------------------------------------------------------------------------
;Jump Medium Kick
[State -1, Jump Medium Kick]
type = ChangeState
value = 640
trigger1 =  command = "b" && (ctrl) && (statetype = A) && (var(59) = 0)
trigger2 = (var(59) = 1) && (ctrl) && (statetype = A) && var(25) != 640 && var(26) = 0 && (P2BodyDist X = [0, 60]) && random >= 900

[State -1, Jump Strong Kick]
type = ChangeState
value = 650
trigger1 =  command = "c" && (ctrl) && (statetype = A) && (var(59) = 0)
trigger2 = (var(59) = 1) && (ctrl) && (statetype = A) && var(25) != 650 && var(26) = 0 && (P2BodyDist X = [0, 80]) && random >= 900
